@@ -1,6 +1,6 @@
 int
 GetPidCommandLine(	int pid,
-					char* cmdParameter
+					SV* cmdParameter
 					);
 
 int
